<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Versão %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 é um programa livre mas o seu desenvolvimento ocupa tempo precioso.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Faça, por favor, uma &lt;a href=&apos;%1&apos;&gt;doação&lt;/a&gt; para apoiar o desenvolvimento do %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Disponibilizado sob a &lt;a href=&apos;%1&apos;&gt;Licença Pública Geral GNU&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Fe&amp;char</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Aquilo que sempre quis saber sobre %1 e nunca se atreveu a perguntar.</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Também pode experimentar as minhas outras aplicaçoes:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, uma aplicação YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, um leitor de música YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Ajude a traduzir o %1 através do serviço %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licenciado a: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Introduza os detalhes da licença</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Endereço eletrónico:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Código:</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Por favor licencie o %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Esta demo expirou.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Se não licenciar a aplicação, a demo expirará em %1 dias.</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Ao comprar a versão completa, estará a contribuir no desenvolvimento do %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Utilizar demo</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Introduza a licença</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Comprar licença</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>A versão completa permite-lhe adicionar mais do que %1 faixas à lista de reprodução e reproduzir as faixas sem interrupção.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Compre em %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Leia mais</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularidade</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Ordem invertida</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Leia mais</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>N.º de faixas</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>N.º de álbuns</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Ano</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Popularidade</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Ordem invertida</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Ordenar por</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Atrás</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Recuar</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Bem-vindo ao &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 precisa de analisar a coleção de músicas.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Utilizar coleção iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Usar %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Escolher uma pasta...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 vai ligar-se aos serviços web Last.fm e copiar os nomes dos artistas e os títulos dos álbuns para procurar capas, biografias e muito mais.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Se tiver alguma dúvida relacionada com privacidade acerca do Minitunes, poderá abandonar agora.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Onde está a sua Biblioteca de música?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Seleccione a localização da sua Biblioteca de música.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Localizar a sua Biblioteca</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Remover</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Já está a decorrer uma análise</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 está a pesquisar a sua Biblioteca de música.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 está a usar &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; para catalogar a sua música.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Isto levará tempo, dependendo do tamanho da sua Biblioteca e da velocidade da ligação de rede.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Vá tomar um café</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Transferência da atualização...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Largue aqui para adicionar à lista de reprodução</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Artistas</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Álbuns</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Pastas</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Reproduzir</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Reproduzir/Pausa</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Parar reprodução após a faixa atual</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Próxima faixa</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Faixa anterior</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Aumentar volume</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Diminuir volume</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Sem som</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Avançar</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Recuar</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Falha na autenticação</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Aceda à %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Utilizador:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Senha:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Registar uma conta %1</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Não se lembra do &lt;a href=&apos;%1&apos;&gt;utilizador&lt;/a&gt; ou da sua &lt;a href=&apos;%2&apos;&gt;senha&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Recuar</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Ir para a vista anterior</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Informações</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Mostrar informação sobre a faixa em curso</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>An&amp;terior</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Ir para a faixa anterior</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>Segui&amp;nte</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Ir para a faixa seguinte</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>Re&amp;produzir</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Iniciar reprodução</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Ecrã completo</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Modo de ecrã completo</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Remover</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Remover faixas selecionadas da lista de reprodução</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Mover para &amp;cima</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Mover para cima as faixas selecionadas</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Mover para &amp;baixo</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Mover para baixo as faixas selecionadas</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Adeus</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>Mudar pasta da &amp;coleção...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Escolher outra pasta para a coleção de músicas</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Sítio &amp;web</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na web</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Efetuar &amp;donativo</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Por favor ajude no desenvolvimento do %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informações do %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Remover todas as faixas da lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>Baral&amp;har</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>Modo de reprodução aleatório</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>R&amp;epetição</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Reproduzir novamente a primeira faixa após todas as outras</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Sem som</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Aplicação</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>Re&amp;produção</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Lista de reprodução</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Aj&amp;uda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Prima %1 para aumentar o volume, %2 para o diminuir</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>A abrir %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Atualização da coleção...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Atualização da coleção - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Coleção atualizada</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Erro fatal: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Erro: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Sair de &amp;ecrã completo</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Tempo restante: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Volume %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Volume nulo</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Volume restaurado</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versão completa</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>O %1 %2 está disponível.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Lembrar mais tarde</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Atualizar</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Janela</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Fe&amp;char</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Comprar %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Pára após esta faixa</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Scrobbling</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Enviar títulos das faixas reproduzidas para a %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Sair de %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Reportar um erro...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation>O %1 terminou a análise da coleção</translation>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Largue aqui os itens</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Lista de reprodução terminada</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Esta é uma versão demo do %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Esta permite que reproduza algumas faixas para que possa testar a aplicação e decidir se gostou.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Obter a versão completa</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Está disponível uma nova versão do %1!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 disponível. A sua versão é a %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Gostaria de a transferir agora?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Ignorar esta versão</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Lembrar mais tarde</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Instalar atualização</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Esta demo está limitada a %1 faixas na lista de reprodução.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Lista de reprodução vazia</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 faixas com dDuração total de %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Procurar</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>A procura não devolveu resultados.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Faixas</translation>
    </message>
</context>
</TS>